@@ -67,7 +67,7 @@ def standardize_dataframe(df: pd.DataFrame, vi_var: str) -> pd.DataFrame:
     if "time" not in df.columns:
         # Use year + day of year if no time column
         df["time"] = pd.to_datetime(
-            df["year"].astype(str) + df["JD"].astype(str),
+            df["year"].astype(str) + df["Doy"].astype(str),
             format="%Y%j"
         )
     else:
@@ -94,7 +94,7 @@ def standardize_dataframe(df: pd.DataFrame, vi_var: str) -> pd.DataFrame:
         if df[vi_var].max() > 1:
             df[vi_var] = (df[vi_var] - 50) / 200
 
-    # Exclude seasons before 2001 if that’s your logic
+    # HACK Exclude seasons before 2001
     df = df[df["Season"] >= 2001]
 
     return df
@@ -507,7 +507,7 @@ class CEIs:
         if not self.redo:
             # If harvest_year is older than last year and file exists, skip
             if (self.harvest_year < (current_year - 1)) and cei_file.is_file():
-                logger.info("CEI file exists and year is old. Skipping: %s", cei_file)
+                logger.info(f"CEI file exists, skipping: {cei_file}")
                 return None
 
         return intermediate_file
