@@ -1,5 +1,6 @@
 import itertools
 import warnings
+import ast
 from multiprocessing import Pool, cpu_count
 from pathlib import Path
 
@@ -48,6 +49,10 @@ class cei_runner(base.BaseGeo):
         self.dir_input = Path(self.parser.get("PATHS", "dir_input"))
         self.base_dir = Path(self.parser.get("PATHS", "dir_crop_inputs"))
         self.do_parallel = self.parser.getboolean("DEFAULT", "do_parallel")
+        
+        # Read countries and methods from config file
+        self.countries = ast.literal_eval(self.parser.get("DEFAULT", "countries"))
+        self.methods = ast.literal_eval(self.parser.get("DEFAULT", "methods"))
 
     def collect_files(self):
         """
@@ -159,28 +164,17 @@ class cei_runner(base.BaseGeo):
             for status, path, filename, admin_zone, category in combinations
         ]
 
-        # Only keep those entries in combinations where the third elemt is
-        # mozambique, south_africa, angola or dem_people's_rep_of_korea
-        # This is done to test the code for these countries
-        combinations = [
-            i
-            for i in combinations
-            if "ukraine" in i[3]
-            # or "lesotho_maize" in i[3] or
-            # #   "namibia_" in i[2] or
-            # "united_republic_of_tanzania_maize" in i[3]
-            # or "zambia_maize" in i[3]
-            # or "zimbabwe_maize" in i[3]
-            # or "south_africa_maize" in i[3]
-            # or "mozambique_maize" in i[3]
-            # or "united_states_of_america" in i[3]
-            or "russian_federation" in i[3]
-            # or "ukraine" in i[3]
-        ]
-        #                 "malawi" in i[2]]
+        # Filter combinations based on countries from config file
+        if self.countries and self.countries != ['all']:
+            combinations = [
+                i
+                for i in combinations
+                if any(country.lower().replace(" ", "_") in i[3].lower() 
+                       for country in self.countries)
+            ]
 
         if self.do_parallel:
-            num_cpu = int(cpu_count() * 0.6)
+            num_cpu = int(cpu_count() * 0.75)
             with Pool(num_cpu) as p:
                 for i, _ in enumerate(p.imap_unordered(indices.process, combinations)):
                     pass
@@ -207,12 +201,12 @@ def run(path_config_files=[]):
     """ Check dictionary keys to have no spaces"""
     indices.validate_index_definitions()
 
-    for method in [
-        "monthly_r",  # "dekad_r"  # "dekad_r"
-    ]:  # , "full_season", "phenological_stages", "fraction_season"]:
-        obj = cei_runner(path_config_files)
+    obj = cei_runner(path_config_files)
+    
+    # Iterate over methods from config file
+    for method in obj.methods:
         obj.main(method)
 
 
 if __name__ == "__main__":
-    run()
+    run()
\ No newline at end of file
