@@ -3,7 +3,6 @@ import os
 import matplotlib.pyplot as plt
 import palettable as pal
 import pandas as pd
-import seaborn as sns
 from tqdm import tqdm
 
 from geocif import utils
@@ -68,6 +67,8 @@ def most_correlated_feature_by_time(df_train, simulation_stages, target_col):
 
 
 def plot_feature_corr_by_time(df, **kwargs):
+    import seaborn as sns
+
     country = kwargs.get("country")
     crop = kwargs.get("crop")
     dir_output = kwargs.get("dir_output")
@@ -163,7 +164,18 @@ def plot_feature_corr_by_time(df, **kwargs):
         fname = f"{country}_{crop}_{id}_corr_feature_by_time.png"
     else:
         fname = f"{country}_{crop}_corr_feature_by_time.png"
-    ax_heatmap.set_title(f"{_country}, {_crop}\n{_region_name}")
+    # first line – big
+    ax_heatmap.set_title(f"{_country}, {_crop}",
+                        fontsize=12,              # larger size
+                        pad=18)                   # push it up a bit
+
+    # second line – smaller, positioned just under the first
+    ax_heatmap.text(0.5, 1.02,                    # x=50 % of axes, y just above top
+                    _region_name,
+                    transform=ax_heatmap.transAxes,
+                    ha='center', va='bottom',
+                    fontsize=8)                  # smaller size
+
 
     # plt.tight_layout()
     os.makedirs(dir_output, exist_ok=True)
@@ -295,16 +307,13 @@ def all_correlated_feature_by_time(df, **kwargs):
                     df_tmp2.loc[idx, "Type"] = combined_dict[row[0]][0]
 
                 # Compute median of each CEI and sort the dataframe based on the absolute value of the median
-                try:
-                    dict_best_cei[region_id] = (
-                        df_tmp2.groupby("Type")
-                        .max()
-                        .reset_index()
-                        .sort_values("Value", ascending=False)["Metric"]
-                        .values
-                    )
-                except:
-                    breakpoint()
+                dict_best_cei[region_id] = (
+                    df_tmp2.groupby("Type")
+                    .max()
+                    .reset_index()
+                    .sort_values("Value", ascending=False)["Metric"]
+                    .values
+                )
 
                 kwargs["region_id"] = region_id
                 _region_names = ", ".join([str(x) for x in group['Region'].unique()])
