@@ -3,6 +3,7 @@ from collections import Counter
 import numpy as np
 import pandas as pd
 from scipy.stats import pearsonr as pearsonr
+from tqdm import tqdm
 
 
 def extract_regions(X, y, regions=[]):
@@ -32,10 +33,7 @@ def _compute_correlations(X, y):
         f_series = X[feature]
 
         # Ignore NaN values in either y or f_series
-        try:
-            mask = ~(np.isnan(y) | np.isnan(f_series))
-        except:
-            breakpoint()
+        mask = ~(np.isnan(y) | np.isnan(f_series))
         y_filtered = y[mask]
         f_series_filtered = f_series[mask]
 
@@ -107,57 +105,47 @@ def get_top_correlated_features(inputs, targets):
     return feature_by_region, counter
 
 
-def get_all_features_correlation(inputs, targets, method):
+def get_all_features_correlation(inputs: pd.DataFrame,
+                                 targets: pd.Series,
+                                 method: str) -> pd.DataFrame:
     """
-    Get the top correlated features for each region
-    :param inputs: pd.DataFrame, input data
-    :param targets: pd.Series, target data
-    :param method: str, method to use to find the top correlated features
+    Fast version – identical output, no length-mismatch on regions whose
+    feature names contain no spaces.
     """
-    frames = []
-    for region_id in inputs["Region"].unique():
-        X, y = extract_regions(inputs, targets, regions=[region_id])
+    numeric_cols = inputs.select_dtypes(include=[np.number]).columns.tolist()
 
-        feature_correlations = _compute_correlations(X, y)
+    df_all = inputs[numeric_cols + ["Region"]].copy()
+    df_all["__target__"] = targets.values
 
-        # Exclude any nan values
-        feature_correlations = {
-            k: v for k, v in feature_correlations.items() if not np.isnan(v)
-        }
+    frames: list[pd.DataFrame] = []
 
-        if not feature_correlations:
+    for region_id, g in tqdm(df_all.groupby("Region", sort=False), leave=False):
+        corr = g[numeric_cols].corrwith(g["__target__"]).round(3).dropna()
+        if corr.empty:
             continue
 
-        split_keys = []
-        for key in feature_correlations.keys():
-            parts = key.split(" ")
-            cei = parts[0]
-            time_period = " ".join(parts[1:])
+        # ---- safe split: always two columns --------------------------------
+        split = (
+            pd.Series(corr.index)            # guarantees a Series
+              .str.split(" ", n=1, expand=True)
+        )
+        if split.shape[1] == 1:              # no spaces in any feature name
+            split[1] = ""                    # match legacy behaviour
+        split.columns = [0, 1]               # make column labels predictable
 
-            split_keys.append([cei, time_period])
+        df_region = (
+            pd.DataFrame({
+                "Metric": split[0].values,
+                method:  split[1].values,
+                "Value": corr.values         # same length as above
+            })
+            .pivot_table(index=method, columns="Metric",
+                         values="Value", aggfunc="first")
+            .reset_index()
+        )
+        df_region.insert(0, "Region", region_id)
+        frames.append(df_region)
 
-        # split_keys = [key.rsplit("_", 1) for key in feature_correlations.keys()]
-        values = list(feature_correlations.values())
+    return pd.concat(frames, ignore_index=True) if frames else pd.DataFrame()
 
-        # Creating a DataFrame
-        df = pd.DataFrame(split_keys, columns=["Metric", method])
-        df["Value"] = values
 
-        # Pivot the DataFrame so each metric becomes a column name and include the year as a separate column
-        df_pivoted = df.pivot_table(
-            index=method, columns="Metric", values="Value", aggfunc="first"
-        ).reset_index()
-        df_pivoted["Region"] = region_id
-        # Move the 'Region' column to the front
-        cols = df_pivoted.columns.tolist()
-        cols = cols[-1:] + cols[:-1]
-        df_pivoted = df_pivoted[cols]
-
-        frames.append(df_pivoted)
-
-    if len(frames):
-        feature_by_region = pd.concat(frames)
-    else:
-        feature_by_region = pd.DataFrame()
-
-    return feature_by_region
