@@ -27,9 +27,7 @@ def compute_last_year_yield(df, target_col="Yield (tn per ha)"):
         unique_years = group["Harvest Year"].unique()
 
         for harvest_year in unique_years:
-            mask = (group["Harvest Year"] == harvest_year - 1) & (
-                group["Region"] == region
-            )
+            mask = (group["Harvest Year"] == harvest_year) & (group["Region"] == region)
             last_year_yield = group.loc[mask, target_col].values
             if last_year_yield:
                 df.loc[
@@ -39,23 +37,32 @@ def compute_last_year_yield(df, target_col="Yield (tn per ha)"):
 
     return df
 
-def compute_closest_years(all_years, harvest_year, number_lag_years):
+def compute_closest_years(all_years, harvest_year, number_lag_years, only_historic=False):
     """
     Finds the historical years closest to a given harvest year,
-    excluding any future year (harvest_year itself and beyond).
+    excluding any future year (harvest_year itself and beyond) based on the only_historic flag.
 
     Args:
         all_years (array-like): List or array of all years to consider.
         harvest_year (int): The year from which to compute distance.
         number_lag_years (int): Number of closest years to return.
+        only_historic (bool): If True, only consider years before the harvest year.
 
     Returns:
         list: The historical years closest to the given harvest year.
               Returns an empty list if no historical years exist.
     """
     # Exclude the harvest year before computation to simplify logic
-    filtered_years = [year for year in all_years if year != harvest_year]
+    if only_historic:
+        filtered_years = [year for year in all_years if year < harvest_year]
+    else:
+        filtered_years = [year for year in all_years if year != harvest_year]
 
+    # If no historical years exist, return an empty list
+    if not filtered_years:
+        return []
+
+    # Sort the years based on their absolute difference from the harvest year
     closest_years = np.array(filtered_years)[
         np.argsort(np.abs(np.array(filtered_years) - harvest_year))[:number_lag_years]
     ]
@@ -150,7 +157,7 @@ def compute_user_median_statistics(df, user_years, target_col="Yield (tn per ha)
 
 
 def compute_lag_yield(
-    df, all_seasons_with_yield, number_lag_years, target_col="Yield (tn per ha)"
+    df, all_seasons_with_yield, forecast_season, number_lag_years, target_col="Yield (tn per ha)"
 ):
     # For the number of years specified in self.number_lag_years, add the yield of that number of years
     # ago to the dataframe
@@ -169,7 +176,7 @@ def compute_lag_yield(
 
         for harvest_year in unique_years:
             closest_years = compute_closest_years(
-                all_seasons_with_yield, harvest_year, number_lag_years
+                all_seasons_with_yield, harvest_year, number_lag_years, only_historic=True
             )
 
             # For each year in the closest years, add the yield to the dataframe as a new column
@@ -414,36 +421,3 @@ def classify_target(df, target_col, number_classes):
     return df, new_target_col, bins
 
 
-# breakpoint()
-
-# from libpysal.weights import Queen, Rook
-# from pysal.lib import weights
-# from scipy.linalg import eigh
-#
-# breakpoint()
-# df = pd.DataFrame()
-#
-# # Create a spatial weights matrix (e.g., Queen contiguity)
-# w = weights.Queen.from_dataframe(dg)
-#
-# # Transform weights to row-standardized form
-# w.transform = 'r'
-#
-# # Convert the weights matrix to a dense format for eigen decomposition
-# W_dense = w.full()[0]
-#
-# # Compute eigenvalues and eigenvectors
-# eigenvalues, eigenvectors = eigh(W_dense)
-#
-# # Sort eigenvalues and corresponding eigenvectors
-# sorted_indices = np.argsort(eigenvalues)[::-1]
-# eigenvalues = eigenvalues[sorted_indices]
-# eigenvectors = eigenvectors[:, sorted_indices]
-#
-# # Select a subset of eigenvectors (e.g., first 10)
-# selected_eigenvectors = eigenvectors[:, :2]
-#
-# breakpoint()
-# # Add eigenvectors to the GeoDataFrame
-# for i in range(selected_eigenvectors.shape[1]):
-#     df[f'EV_{i + 1}'] = selected_eigenvectors[:, i]
