@@ -1,9 +1,11 @@
+import os
+os.environ["MPLBACKEND"] = "Agg"
+
 import numpy as np
 from tqdm import tqdm
 from sklearn.ensemble import RandomForestRegressor
 from collections import Counter
 from pathlib import Path
-import matplotlib.pyplot as plt
 import pandas as pd
 
 
@@ -34,10 +36,12 @@ def are_all_features_non_eo(features):
 
 def select_features(
     X, y,
-    method="RFE",
+    method="multi",
     min_features_to_select=3,
     threshold_nan=0.2,
-    threshold_unique=0.6
+    threshold_unique=0.6,
+    dir_output=".",
+    region=None
 ):
     """
     Feature-selection wrapper supporting many methods plus a new 'multi' option.
@@ -61,7 +65,6 @@ def select_features(
     X_filtered : pd.DataFrame of selected features
     selected_features : list[str]
     """
-
     # copy original for multi-mode recursion
     X_clean = X.copy()
 
@@ -70,21 +73,32 @@ def select_features(
     X_clean = X_clean.loc[:, nan_prop <= threshold_nan]
 
     # 2) fill NaNs with median
-    X_clean = X_clean.fillna(X_clean.median())
+    num_cols = X_clean.select_dtypes(include=["number"]).columns  # catches int64, float64, etc.
+    X_clean[num_cols] = X_clean[num_cols].fillna(X_clean[num_cols].median())
 
     # --- multi-method ensemble -------------------------------
     if method == "multi":
+        import matplotlib.pyplot as plt
+        import seaborn as sns
+
         counter = Counter()
+        selections = {}
+
+        models = ["Leshy", "BorutaPy", "mrmr"]
         # run three selectors and count feature picks
-        for sub_m in ["BorutaPy", "mrmr"]:
-            _, _, feats = select_features(
-                X_clean, y,
-                method=sub_m,
-                min_features_to_select=min_features_to_select,
-                threshold_nan=threshold_nan,
-                threshold_unique=threshold_unique
-            )
-            print(sub_m, feats)
+        for sub_m in models:
+            try:
+                _, _, feats = select_features(
+                    X_clean, y,
+                    method=sub_m,
+                    min_features_to_select=min_features_to_select,
+                    threshold_nan=threshold_nan,
+                    threshold_unique=threshold_unique
+                )
+            except:
+                feats = []
+
+            selections[sub_m] = set(feats)
             counter.update(feats)
 
         # union of all features
@@ -97,14 +111,29 @@ def select_features(
         fig = freq.plot(kind="bar", width=0.9).get_figure()
         plt.title("Feature selection frequency across methods")
         plt.xlabel("Feature")
-        plt.ylabel("Times selected (out of 3)")
+        plt.ylabel(f"Times selected (out of {len(models)})")
         plt.tight_layout()
 
-        out_dir = Path("feature_selection_multi")
-        out_dir.mkdir(parents=True, exist_ok=True)
-        fig.savefig(out_dir / "feature_selection_frequency.png", dpi=300)
+        dir_output = dir_output / Path("feature_selection")
+        os.makedirs(dir_output, exist_ok=True)
+        fig.savefig(dir_output / f"feature_selection_frequency_{region}.png", dpi=300)
         plt.close(fig)
 
+        # build DataFrame: rows=features, cols=methods, 1 if selected
+        sel_df = pd.DataFrame(
+            {m: [1 if f in selections[m] else 0 for f in combined] for m in models},
+            index=combined
+        )
+
+        fig2, ax2 = plt.subplots(figsize=(10, max(6, len(combined) * 0.3)))
+        sns.heatmap(sel_df, annot=True, cbar=False, linewidths=0.5, ax=ax2)
+        ax2.set_xlabel("Method")
+        ax2.set_ylabel("Feature")
+        ax2.set_title("Which features each method selected")
+        plt.tight_layout()
+        fig2.savefig(dir_output / f"feature_selection_methods_{region}.png", dpi=300)
+        plt.close(fig2)
+
         return None, X_out, combined
 
     # define forest for methods that need it
@@ -222,14 +251,36 @@ def select_features(
 
     elif method == "BorutaPy":
         from boruta import BorutaPy
-        sel = BorutaPy(forest, n_estimators="auto", random_state=42, verbose=0)
-        sel.fit(X_clean.values, y)
-        mask = sel.support_ | sel.support_weak_
-        selected = X_clean.columns[mask].tolist()
+        from collections import Counter
+        import itertools as it
+
+        region_selected = {}
+        for region in X_clean["Region"].unique():
+            print(region, "\n")
+            idx = X_clean["Region"] == region
+            X_region = X_clean.loc[idx].drop(columns=["Region"])
+            y_region = y.loc[idx] if hasattr(y, "loc") else y[idx]
+
+            sel = BorutaPy(
+                estimator=forest,
+                n_estimators="auto",
+                random_state=42,
+                verbose=0          
+            )
+
+            sel.fit(X_region.values, y_region)
+            region_selected[region] = (
+                X_region.columns[sel.support_ | sel.support_weak_].tolist()
+            )
+
+        # ─── 3. keep features chosen in ≥ 1 regions ------------------------------
+        counts   = Counter(it.chain.from_iterable(region_selected.values()))
+        selected = [feat for feat, n in counts.items() if n >= 1]
 
     elif method == "Leshy":
         import arfs.feature_selection.allrelevant as arfsgroot
         from catboost import CatBoostRegressor
+
         model = CatBoostRegressor(n_estimators=350, verbose=0, use_best_model=False)
         sel = arfsgroot.Leshy(
             model,
@@ -241,7 +292,6 @@ def select_features(
         )
         sel.fit(X_clean, y)
         selected = sel.get_feature_names_out()
-
     elif method == "PowerShap":
         from powershap import PowerShap
         from catboost import CatBoostRegressor
@@ -300,7 +350,7 @@ def select_features(
 
     else:
         raise ValueError(f"Unknown method: {method}")
-
+    
     # post-filtering: non-EO fallback to SelectKBest
     non_eo = are_all_features_non_eo(selected)
     if non_eo or method == "SelectKBest":
