@@ -6,6 +6,20 @@ import pandas as pd
 from geocif import utils
 
 
+def make_serializable(hparams):
+    serializable = hparams.copy()
+
+    # Convert callbacks to strings
+    if 'callbacks' in serializable:
+        serializable['callbacks'] = [str(cb) for cb in serializable['callbacks']]
+
+    # Convert terms to string
+    if 'terms' in serializable:
+        serializable['terms'] = str(serializable['terms'])
+
+    return serializable
+
+
 def config_to_dict(parser):
     """
     Reads a configuration file and returns the configuration as a nested dictionary.
@@ -103,6 +117,9 @@ def store(db_path, experiment_id, df, model, model_name):
     for col in df.select_dtypes(include=["category"]).columns:
         df[col] = df[col].astype(str)
 
+    # Convert all columns to string
+    df['Best Hyperparameters'] = df['Best Hyperparameters'].apply(make_serializable)
+
     # Output results to database
     try:
         utils.to_db(db_path, experiment_id, df)
