@@ -1,5 +1,6 @@
 import numpy as np
 from typing import Union
+from tqdm import tqdm
 
 from geocif import utils
 
@@ -46,14 +47,16 @@ def add_stage_information(df, method):
         df["Starting Stage"].map(dict) + " - " + df["Ending Stage"].map(dict)
     )
 
-    # Group by Region, Harvest Year
-    # For each group, add a column called Percentage Season
-    # that is the percentage of the season that has passed based on the number of rows
-    # in the group
+    df["Percentage Season"] = float("nan")
+
+    # Group by Region and Harvest Year
     grouped = df.groupby(["Region", "Harvest Year"])
-    df["Percentage Season"] = (
-        grouped.cumcount() * 100.0 / grouped["CEI"].transform("size")
-    )
+
+    # Loop through groups with tqdm
+    for (region, year), group in tqdm(grouped, desc="Computing Percentage Season"):
+        idx = group.index
+        n = len(group)
+        df.loc[idx, "Percentage Season"] = [i * 100.0 / n for i in range(n)]
 
     return df
 
