@@ -18,7 +18,7 @@ def get_yld_prd(df, name_crop, cntr, region, calendar_year, region_column="ADM1_
 
     """
     # Get yield and production for country for specific year
-    val = np.NaN
+    val = np.nan
 
     # df.columns.values: [u'ADM0_NAME', u'ADM1_NAME', u'ADM2_NAME', u'str_ID', u'num_ID', 1990 ... 2015]
     if calendar_year in df.columns:
@@ -38,6 +38,8 @@ def get_yld_prd(df, name_crop, cntr, region, calendar_year, region_column="ADM1_
                 df_tmp = df.loc[df.Season == "Single-cropping and Middle-season Rice"]
             elif cntr == "India":
                 df_tmp = df.loc[df.Season == "Kharif"]
+            elif cntr == "Bangladesh":  # HACK for Bangladesh rice
+                df_tmp = df.loc[df.Season_J == "Boro"]
         elif name_crop == "maize" and cntr in [
             "Austria",
             "Belgium",
@@ -88,7 +90,7 @@ def get_yld_prd(df, name_crop, cntr, region, calendar_year, region_column="ADM1_
 
             try:
                 if val.isnull().all():
-                    val = np.NaN
+                    val = np.nan
                 else:
                     val = val.values[0]
             except:
@@ -97,10 +99,10 @@ def get_yld_prd(df, name_crop, cntr, region, calendar_year, region_column="ADM1_
         else:
             # The values[-1] is a hack to accommodate multiple types of green maize
             vals = df[calendar_year]
-            val = vals.values[-1] if not vals.empty else np.NaN
+            val = vals.values[-1] if not vals.empty else np.nan
 
     # Replace yield/production value of 0 with NaN
-    val = np.NaN if val == 0.0 else val
+    val = np.nan if val == 0.0 else val
 
     return val
 
@@ -120,7 +122,7 @@ def add_GEOGLAM_statistics(dir_stats, df, stats, method, admin_zone):
     """
     # Create empty columns for all the ag statistics
     for stat in stats:
-        df.loc[:, stat] = np.NaN
+        df.loc[:, stat] = np.nan
 
     # Fill in the ag statistics columns with data when available
     # Compute national scale statistics
@@ -130,7 +132,12 @@ def add_GEOGLAM_statistics(dir_stats, df, stats, method, admin_zone):
     season = df["Season"].unique()[0]
 
     # Read in the area stats for the crop and season
-    stat_file = dir_stats / f"{crop}_{season}.xlsx"
+    # HACK: Bangladesh rice uses country-specific filename
+    country = df["Country"].unique()[0]
+    if crop == "rice" and country.lower() == "bangladesh":
+        stat_file = dir_stats / "bangladesh_rice.xlsx"
+    else:
+        stat_file = dir_stats / f"{crop}_{season}.xlsx"
 
     for stat in stats:
         if os.path.isfile(stat_file):
@@ -196,22 +203,30 @@ def add_statistics(
     Returns:
 
     """
+    # HACK: Bangladesh rice uses GEOGLAM format
+    if country == "Bangladesh" and crop == "Rice":
+        df = add_GEOGLAM_statistics(dir_stats, df, stats, method, admin_zone)
+        # Add columns for obj.stats_cols
+        for col in ["Area"]:
+            df.loc[:, col] = np.nan
+        return df
+    
     # First check if country and crop are in the admin_crop_production.csv file
-    if country == "Afghanistan":
-        fn = "afghanistan.csv"
-    elif country == "Illinois":
+    #if country == "Afghanistan":
+    #    fn = "afghanistan.csv"
+    if country == "Illinois":
         fn = "illinois.csv"
     elif country == "Ethiopia":
         # HACK
-        fn = "adm_crop_production.csv"
+        fn = "hvstat_africa_data_v1.0.csv"
     else:
-        fn = "adm_crop_production.csv"
+        fn = "hvstat_africa_data_v1.0.csv"
     df_fewsnet = pd.read_csv(dir_stats / fn, low_memory=False)
     # HACK
-    if country == "Afghanistan":
-        df_fewsnet.loc[:, "product"] = (
-            df_fewsnet["season_name"] + " " + df_fewsnet["product"]
-        )
+    #if country == "Afghanistan":
+    #    df_fewsnet.loc[:, "product"] = (
+    #        df_fewsnet["season_name"] + " " + df_fewsnet["product"]
+    #    )
 
     # Hack replace Wheat in product column in df_fewsnet with Winter Wheat
     if "product" in df_fewsnet.columns:
@@ -220,6 +235,10 @@ def add_statistics(
     # Check if country and crop exist in the fewsnet database
     mask = (df_fewsnet["country"] == country) & (df_fewsnet["product"] == crop)
 
+    # If qc_flag column exists, filter out rows with qc_flag != 0
+    if "qc_flag" in df_fewsnet.columns:
+        df_fewsnet = df_fewsnet[df_fewsnet["qc_flag"] == 0]
+
     if mask.sum() == 0:
         df = add_GEOGLAM_statistics(dir_stats, df, stats, method, admin_zone)
     else:
@@ -241,6 +260,7 @@ def add_statistics(
                         "All (PS)",
                         "irrigated",
                         "rainfed",
+                        "Rainfed (PS)"
                     ]
                 )
                 & (df_fewsnet["harvest_year"] == harvest_year)
@@ -256,20 +276,14 @@ def add_statistics(
                         "Winter",
                     ]
                 )
-                & (df_fewsnet["indicator"].isin(["yield", "area", "production"]))
             )
 
-            # Fetching values for each indicator
-            yield_value = df_fewsnet.loc[
-                mask_yield & mask_region & (df_fewsnet["indicator"] == "yield"), "value"
-            ]
-            area_value = df_fewsnet.loc[
-                mask_yield & mask_region & (df_fewsnet["indicator"] == "area"), "value"
-            ]
-            prod_value = df_fewsnet.loc[
-                mask_yield & mask_region & (df_fewsnet["indicator"] == "production"),
-                "value",
-            ]
+            # Fetching values for each statistic
+            mask_combined = mask_yield & mask_region
+
+            yield_value = df_fewsnet.loc[mask_combined, "yield"]
+            area_value = df_fewsnet.loc[mask_combined, "area"]
+            prod_value = df_fewsnet.loc[mask_combined, "production"]
 
             # Replace any inf or 0 values by NaN
             yield_value = yield_value.replace([0, np.inf, -np.inf], np.nan)
@@ -297,4 +311,4 @@ def add_statistics(
     for col in ["Area"]:
         df.loc[:, col] = np.nan
 
-    return df
+    return df
\ No newline at end of file
