@@ -303,7 +303,47 @@ def auto_train(
         elif model_name == "tabpfn":
             from tabpfn_extensions.post_hoc_ensembles.sklearn_interface import AutoTabPFNRegressor
 
-            model = AutoTabPFNRegressor()
+            # Identify the column indices for cat_features in X_train
+            if cat_features is None:
+                cat_feature_indices = []
+            else:
+                cat_feature_indices = [X_train.columns.get_loc(col) for col in cat_features if
+                    col in X_train.columns]
+
+            model = AutoTabPFNRegressor(max_time=600,
+                                        #categorical_feature_indices=cat_feature_indices,
+                                        ignore_pretraining_limits=True)
+        elif model_name == "desreg":
+            from desReg.des.DESRegression import DESRegression
+            from tabpfn_extensions.post_hoc_ensembles.sklearn_interface import AutoTabPFNRegressor
+            from catboost import CatBoostRegressor
+
+            model_catboost = CatBoostRegressor(**hyperparams, cat_features=cat_features)
+
+            # Identify the column indices for cat_features in X_train
+            if cat_features is None:
+                cat_feature_indices = []
+            else:
+                cat_feature_indices = [X_train.columns.get_loc(col) for col in cat_features if
+                    col in X_train.columns]
+            model_tabpfn = AutoTabPFNRegressor(max_time=600,
+                                               # categorical_feature_indices=cat_feature_indices,
+                                               ignore_pretraining_limits=True)
+            
+            import ydf
+            templates = ydf.GradientBoostedTreesLearner.hyperparameter_templates()
+            task = ydf.Task.REGRESSION if model_type == "REGRESSION" else ydf.Task.CLASSIFICATION
+            model_ydf = ydf.GradientBoostedTreesLearner(
+                label=target_col, task=task,
+                growing_strategy='BEST_FIRST_GLOBAL',
+                categorical_algorithm='RANDOM',
+                split_axis='SPARSE_OBLIQUE',
+                sparse_oblique_normalization='MIN_MAX',
+                sparse_oblique_num_projections_exponent=2.0
+            )
+            hyperparams = templates["benchmark_rank1v1"]
+
+            model = DESRegression(regressors_list=[model_catboost, model_ydf])
         elif model_name == "ngboost":
             if model_type == "REGRESSION":
                 from ngboost import NGBRegressor
@@ -329,7 +369,8 @@ def auto_train(
                 categorical_algorithm='RANDOM',
                 split_axis='SPARSE_OBLIQUE',
                 sparse_oblique_normalization='MIN_MAX',
-                sparse_oblique_num_projections_exponent=2.0
+                sparse_oblique_num_projections_exponent=2.0,
+                validation_ratio=0.0,
             )
             hyperparams = templates["benchmark_rank1v1"]
 
@@ -350,10 +391,9 @@ def auto_train(
                 "cumulative_2": s(0) + s(1) + te(0, 1) + f(2),
                 "cumulative_3": s(0) + s(1) + s(2) + te(0, 1) + te(0, 2) + te(1, 2) + f(3),
             }
-
+            breakpoint()
             formula = gam_formulas.get(model_name, gam_cls(n_splines=25, spline_order=3))
-            model = GAM(formula).gridsearch(X_train.values, y_train.values, lam=np.logspace(-3, 3, 11)) if model_name.startswith("gam") else formula
-
+            model = gam_cls(n_splines=25, spline_order=3).gridsearch(X_train, y_train.values, lam=np.logspace(-3, 3, 11)) if model_name.startswith("gam") else formula
         elif model_name == "geospaNN":
             import torch
             import geospaNN
@@ -376,10 +416,12 @@ def auto_train(
             model = geospaNN.nngls(p=p, neighbor_size=nn, coord_dimensions=2, mlp=mlp, theta=torch.tensor(theta0))
             model = geospaNN.nngls_train(model, lr=0.01, min_delta=0.001)
             training_log = model.train(data_train, data_val, data_test, Update_init=10, Update_step=10)
+        elif model_name == "cubist":
+            from cubist import Cubist
 
+            model = Cubist(n_committees=5, auto=True, random_state=seed)
         elif model_name == "xgboost":
             raise NotImplementedError("XGBoost model not implemented yet")
-
         else:
             raise ValueError(f"Unknown model name: {model_name}")
 
