@@ -301,7 +301,7 @@ def plot_df_shpfile(
 
             norm = BoundaryNorm(ticks, ncolors=cmap.mpl_colormap.N, clip=True)
             cbaxes = inset_axes(
-                ax, width="60%", height="3%", loc=loc_legend, borderpad=0.25
+                ax, width="75%", height="3%", loc=loc_legend, borderpad=0.25
             )
             sm = plt.cm.ScalarMappable(norm=norm, cmap=cmap.mpl_colormap)
             # sm._A = []
@@ -328,7 +328,7 @@ def plot_df_shpfile(
             # plt.setp(cb.ax.xaxis.get_ticklines(), alpha=0.6)
             # Do not show first and last tick label
             ticks[0] = ""
-            ticks[-1] = ""
+            # ticks[-1] = ""
             cb.ax.set_title(
                 label, fontsize=8, fontweight="semibold", fontfamily="Arial"
             )
@@ -395,23 +395,16 @@ def plot_df_shpfile(
                 )
                 _name_country.append(cntr.replace(" ", "_").lower())
 
-            # Hack
-            if _name_country[0] == "russian_federation":
-                extent = [20, 80, 40, 80]
-            else:
-                extent = rgeo.get_country_lat_lon_extent(
-                    _name_country, buffer=1.0
-                )  # left, right, bottom, top
+            extent = rgeo.get_country_lat_lon_extent(
+                _name_country, buffer=1.0
+            )  # left, right, bottom, top
 
-                # Hack: Add space to the top for adding title
-                extent[3] = extent[3] + 2
-                # Add some space to the bottom for adding legend and colorbar
-                extent[2] = extent[2] - 3
+            # Hack: Add space to the top for adding title
+            extent[3] = extent[3] + 2
+            # Add some space to the bottom for adding legend and colorbar
+            extent[2] = extent[2] - 3
 
-            try:
-                ax.set_extent(extent)
-            except:
-                breakpoint()
+            ax.set_extent(extent)
         elif name_country == "world":
             ax.add_feature(
                 cartopy.feature.LAND.with_scale("50m"), color="white"
